==> oauth2-oidc-sdk-9.43.4-sources.jar: com/nimbusds/openid/connect/sdk/assurance/request/VerificationSpec.java <==
/*
 * oauth2-oidc-sdk
 *
 * Copyright 2012-2021, Connect2id Ltd and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.nimbusds.openid.connect.sdk.assurance.request;


import net.minidev.json.JSONObject;


/**
 * The {@code verification} sub-element within an OpenID Connect
 * {@link VerifiedClaimsSetRequest request for verified claims}.
 *
 * <p>Example:
 *
 * <pre>
 * {
 *   "trust_framework": null,
 *   "time": null,
 *   "evidence": [
 *     {
 *       "type": {
 *         "value": "document"
 *       },
 *       "method": null,
 *       "document_details": {
 *         "type": null
 *       }
 *     }
 *   ]
 * }
 * </pre>
 *
 * <p>Related specifications:
 *
 * <ul>
 *     <li>OpenID Connect for Identity Assurance 1.0, section 6.
 * </ul>
 */
public interface VerificationSpec {
	
	
	/**
	 * Returns a JSON object representation of the verification element.
	 *
	 * <p>Example:
	 *
	 * <pre>
	 * {
	 *   "trust_framework": null,
	 *   "time": null,
	 *   "evidence": [
	 *     {
	 *       "type": {
	 *         "value": "document"
	 *       },
	 *       "method": null,
	 *       "document_details": {
	 *         "type": null
	 *       }
	 *     }
	 *   ]
	 * }
	 * </pre>
	 *
	 * @return The JSON object.
	 */
	JSONObject toJSONObject();
}

==> oauth2-oidc-sdk-11.26.1-sources.jar: com/nimbusds/openid/connect/sdk/assurance/request/VerificationSpec.java <==
/*
 * oauth2-oidc-sdk
 *
 * Copyright 2012-2021, Connect2id Ltd and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.nimbusds.openid.connect.sdk.assurance.request;


import net.minidev.json.JSONObject;


/**
 * The {@code verification} sub-element within an OpenID Connect
 * {@link VerifiedClaimsSetRequest request for verified claims}.
 *
 * <p>Example:
 *
 * <pre>
 * {
 *   "trust_framework": null,
 *   "time": null,
 *   "evidence": [
 *     {
 *       "type": {
 *         "value": "document"
 *       },
 *       "method": null,
 *       "document_details": {
 *         "type": null
 *       }
 *     }
 *   ]
 * }
 * </pre>
 *
 * <p>Related specifications:
 *
 * <ul>
 *     <li>OpenID Connect for Identity Assurance 1.0
 * </ul>
 */
public interface VerificationSpec {
	
	
	/**
	 * Returns a JSON object representation of the verification element.
	 *
	 * <p>Example:
	 *
	 * <pre>
	 * {
	 *   "trust_framework": null,
	 *   "time": null,
	 *   "evidence": [
	 *     {
	 *       "type": {
	 *         "value": "document"
	 *       },
	 *       "method": null,
	 *       "document_details": {
	 *         "type": null
	 *       }
	 *     }
	 *   ]
	 * }
	 * </pre>
	 *
	 * @return The JSON object.
	 */
	JSONObject toJSONObject();
}
